@@ -3,9 +3,8 @@ cx      SUBROUTINE PERIODF(Y,N,IWINDW,OUTMIN,OUTMAX,PE,SPE,NP)
 ccb      SUBROUTINE PERIODF(Y,N,IWINDW,OUTMIN,OUTMAX,PE,SPE,NP,IFG)
 ccxx      SUBROUTINE PERIODF(Y,N,NP,IWINDW,OUTMIN,OUTMAX,PE,SPE,IFG)
       SUBROUTINE PERIODF(Y,N,NP,IWINDW,LAG,OUTMIN,OUTMAX,PE,SPE,IFG)
-
 C
-      INCLUDE 'TSSS_f.h'
+      INCLUDE 'TSSS.h'
 C
 C  ...  This program computes periodogram  ...
 C
@@ -29,10 +28,11 @@ cc      DIMENSION  Y(NMAX), PE(0:NF), SPE(0:NF), COV(0:MJ)
 ccb      DIMENSION  Y(N), PE(0:NF), SPE(0:NF), COV(0:1024)
 cxx      DIMENSION  Y(N), PE(0:NP), SPE(0:NP), COV(0:1024)
 C
-      INTEGER :: N, NP, IWINDW, IFG
-      REAL(8) :: Y(N), OUTMIN, OUTMAX, PE(0:NP), SPE(0:NP)
-ccxx      REAL(8) :: COV(0:1024)
-      REAL(8) :: COV(0:LAG)
+      INTEGER N, NP, IWINDW, IFG
+      DOUBLE PRECISION Y(N), OUTMIN, OUTMAX, PE(0:NP), SPE(0:NP)
+c local
+ccxx      DOUBLE PRECISION COV(0:1024)
+      DOUBLE PRECISION COV(0:LAG)
 C
 cc      DATA  OUTMIN/-1.0D30/, OUTMAX/ 1.0D30/
 C
@@ -77,10 +77,11 @@ cxx      IMPLICIT REAL*8(A-H,O-Z)
 ccb      DIMENSION  Y(N), COV(0:1024), P(0:512), FC(513), FS(513)
 cxx      DIMENSION  Y(N), COV(0:1024), P(0:NN), FC(NN+1), FS(NN+1)
 C
-      INTEGER :: N, LAG, NN, ISW
-ccxx      REAL(8) :: Y(N), OUTMIN, OUTMAX, COV(0:1024), P(0:NN)
-      REAL(8) :: Y(N), OUTMIN, OUTMAX, COV(0:LAG), P(0:NN)
-      REAL(8) :: FC(NN+1), FS(NN+1), YMEAN
+      INTEGER N, LAG, NN, ISW
+ccxx      DOUBLE PRECISION Y(N), OUTMIN, OUTMAX, COV(0:1024), P(0:NN)
+      DOUBLE PRECISION Y(N), OUTMIN, OUTMAX, COV(0:LAG), P(0:NN)
+c local
+      DOUBLE PRECISION FC(NN+1), FS(NN+1), YMEAN
 C
 ccxx      IF( LAG.GE.1023 )  LAG = 1023
       IF( ISW.EQ.0 )  CALL  AUTCOV( Y,N,LAG,OUTMIN,OUTMAX,COV,YMEAN )
